@@ -1,7 +1,7 @@
 package Config::IOD::Base;
 
 our $DATE = '2015-03-19'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -27,7 +27,7 @@ sub new {
     $attrs{enable_bracket}  //= 1;
     $attrs{enable_brace}    //= 1;
     $attrs{enable_expr}     //= 0;
-    $attrs{ignore_unknown_encoding} //= 0;
+    $attrs{ignore_unknown_directive} //= 0;
     # allow_encodings
     # disallow_encodings
     # allow_directives
@@ -428,7 +428,7 @@ Config::IOD::Base - Base class for Config::IOD and Config::IOD::Reader
 
 =head1 VERSION
 
-This document describes version 0.11 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2015-03-19.
+This document describes version 0.12 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2015-03-19.
 
 =head1 ATTRIBUTES
 
@@ -546,7 +546,7 @@ config file and force user to use JSON encoding or bracket to specify array:
  [section]
  a=[1,2]
 
-=head2 ignore_unknown_encoding => bool (default: 0)
+=head2 ignore_unknown_directive => bool (default: 0)
 
 If set to true, will not die if an unknown directive is encountered. It will
 simply be ignored as a regular comment.
